package sun.management.snmp.jvmmib;

import javax.management.ObjectName;
import com.sun.jmx.snmp.SnmpStatusException;
import com.sun.jmx.snmp.SnmpOid;
import com.sun.jmx.snmp.agent.SnmpMibSubRequest;
import javax.management.MBeanServer;
import com.sun.jmx.snmp.agent.SnmpMib;
import com.sun.jmx.snmp.agent.SnmpStandardObjectServer;
import java.io.Serializable;
import com.sun.jmx.snmp.agent.SnmpMibTable;

public class JvmMemPoolTableMeta extends SnmpMibTable implements Serializable
{
    static final long serialVersionUID = -2799470815264898659L;
    private JvmMemPoolEntryMeta node;
    protected SnmpStandardObjectServer objectserver;
    
    public JvmMemPoolTableMeta(SnmpMib snmpMib, SnmpStandardObjectServer objectserver) {
        super(snmpMib);
        this.objectserver = objectserver;
    }
    
    protected JvmMemPoolEntryMeta createJvmMemPoolEntryMetaNode(String s, String s2, SnmpMib snmpMib, MBeanServer mBeanServer) {
        return new JvmMemPoolEntryMeta(snmpMib, this.objectserver);
    }
    
    public void createNewEntry(SnmpMibSubRequest snmpMibSubRequest, SnmpOid snmpOid, int n) throws SnmpStatusException {
        if (this.factory != null) {
            this.factory.createNewEntry(snmpMibSubRequest, snmpOid, n, this);
            return;
        }
        throw new SnmpStatusException(6);
    }
    
    public boolean isRegistrationRequired() {
        return false;
    }
    
    public void registerEntryNode(SnmpMib snmpMib, MBeanServer mBeanServer) {
        this.node = this.createJvmMemPoolEntryMetaNode("JvmMemPoolEntry", "JvmMemPoolTable", snmpMib, mBeanServer);
    }
    
    public synchronized void addEntry(SnmpOid snmpOid, ObjectName objectName, Object o) throws SnmpStatusException {
        if (!(o instanceof JvmMemPoolEntryMBean)) {
            throw new ClassCastException("Entries for Table \"JvmMemPoolTable\" must implement the \"JvmMemPoolEntryMBean\" interface.");
        }
        super.addEntry(snmpOid, objectName, o);
        return;
    }
    
    public void get(SnmpMibSubRequest snmpMibSubRequest, SnmpOid snmpOid, int n) throws SnmpStatusException {
        JvmMemPoolEntryMBean instance = (JvmMemPoolEntryMBean)this.getEntry(snmpOid);
        synchronized (this) {
            this.node.setInstance(instance);
            this.node.get(snmpMibSubRequest, n);
        }
    }
    
    public void set(SnmpMibSubRequest snmpMibSubRequest, SnmpOid snmpOid, int n) throws SnmpStatusException {
        if (snmpMibSubRequest.getSize() == 0) {
            return;
        }
        JvmMemPoolEntryMBean instance = (JvmMemPoolEntryMBean)this.getEntry(snmpOid);
        synchronized (this) {
            this.node.setInstance(instance);
            this.node.set(snmpMibSubRequest, n);
        }
        return;
    }
    
    public void check(SnmpMibSubRequest snmpMibSubRequest, SnmpOid snmpOid, int n) throws SnmpStatusException {
        if (snmpMibSubRequest.getSize() == 0) {
            return;
        }
        JvmMemPoolEntryMBean instance = (JvmMemPoolEntryMBean)this.getEntry(snmpOid);
        synchronized (this) {
            this.node.setInstance(instance);
            this.node.check(snmpMibSubRequest, n);
        }
        return;
    }
    
    public void validateVarEntryId(SnmpOid snmpOid, long n, Object o) throws SnmpStatusException {
        this.node.validateVarId(n, o);
    }
    
    public boolean isReadableEntryId(SnmpOid snmpOid, long n, Object o) throws SnmpStatusException {
        return this.node.isReadable(n);
    }
    
    public long getNextVarEntryId(SnmpOid snmpOid, long n, Object o) throws SnmpStatusException {
        long n2;
        for (n2 = this.node.getNextVarId(n, o); !this.isReadableEntryId(snmpOid, n2, o); n2 = this.node.getNextVarId(n2, o)) {}
        return n2;
    }
    
    public boolean skipEntryVariable(SnmpOid snmpOid, long n, Object o, int n2) {
        try {
            JvmMemPoolEntryMBean instance = (JvmMemPoolEntryMBean)this.getEntry(snmpOid);
            synchronized (this) {
                this.node.setInstance(instance);
                return this.node.skipVariable(n, o, n2);
            }
        }
        catch (SnmpStatusException ex) {
            return false;
        }
    }
}
